\name{BEZ}
\alias{BEZ}
\title{Z score approximation of contrast significance}
\description{
 calculates a Z score approximation of contrast significance
}
\usage{
 BEZ(rankarray,lambda)
}
\arguments{
  \item{rankarray}{matrix of ranks}
  \item{lambda}{contrast coefficient vector}
}
\details{
 \code{BEZ} calculates a Z score approximation of the probability that the
 deviation of the mean rank scores from the contrast coefficient vector would
 occur given randomly allocated ranks. It is only useful in conjuction with
 the /code{kendall.w} function.
}
\value{
  \item{Z}{Z score}
}
\author{Jim Lemon}
\seealso{\code{\link{kendall.w}}}
\keyword{misc}

\eof
\name{cohen.kappa}
\alias{cohen.kappa}
\title{kappa reliability coefficient for nominal data}
\description{
 calculates the kappa coefficient of reliability for nominal data
}
\usage{
cohen.kappa(classif, type=c("score","count"))
}
\arguments{
  \item{classif}{matrix of classification counts or scores}
  \item{type}{whether classif is an object by method matrix of scores
   or an object by category matrix of counts}
}
\details{
 \code{cohen.kappa} will accept either an object by category matrix of counts
 in which the numbers represent how many methods have placed the object
 in each category, or an object by method matrix of categories in which
 the numbers represent each method's categorization of that object. The
 default is to assume scores and the operator \bold{must} specify if counts
 are used.
 \code{cohen.kappa} reports two or three kappa values. If the classification
 matrix is composed of scores, the first is the original calculation from 
 Cohen(1960) which does not assume equal classification proportions for the 
 different methods. The next value is calculated as in Siegel & Castellan 
 (1988) and uses pooled classification proportions. This method provides an 
 adjustment for bias, where the different methods systematically differ in 
 their categorization. The third value is adjusted for prevalence using the 
 method proposed by Byrt, Bishop and Carlin (1993). An approximate 
 distribution of this statistic does not seem to be available, so there is 
 no approximation or probability reported.
}
\value{
  \item{kappa.c}{value of kappa (Cohen)}
  \item{kappa.sc}{value of kappa (Siegel & Castellan)}
  \item{kappa.bbc}{value of kappa (Byrt, Bishop & Carlin)}
  \item{Zc}{the Z-score approximation for kappa.c}
  \item{Zsc}{the Z-score approximation for kappa.sc}
  \item{pc}{the probability for Zc}
  \item{psc}{the probability for Zsc}
}
\references{
 {Byrt, T., Bishop, J. & Carlin, J.B. (1993) Bias, Prevalence and Kappa.
  Journal of Clinical Epidemiology, 46(5): 423-429.}
 {Cohen, J. (1960) A coefficient of agreement for nominal scales.
  Educational and Psychological Measurement, 20: 37-46.}
 {Siegel, S. & Castellan, N.J.Jr. (1988) Nonparametric
 statistics for the behavioral sciences. Boston, MA: McGraw-Hill.}
}
\author{Jim Lemon}
\note{This is sometimes called Cohen's kappa. The name also avoids confusion
 with the kappa estimate of the conditioning number of a matrix. For a 
 contingency table version of this statistic, see \code{classAgreement}
 in package e1071}
\seealso{\code{\link{scores.to.counts}},\code{\link{wtpc}}}
\examples{
 # the "C" data from Krippendorff
 nmm<-matrix(c(1,1,NA,1,2,2,3,2,3,3,3,3,3,3,3,3,2,2,2,2,1,2,3,4,4,4,4,4,
 1,1,2,1,2,2,2,2,NA,5,5,5,NA,NA,1,1,NA,NA,3,NA),nrow=4)
 # first show the score to count transformation, remembering that
 # Krippendorff's data is classifier by object and must be transposed
 scores.to.counts(t(nmm))
 # now calculate kappa - note that Cohen's method does not work with NAs
 cohen.kappa(t(nmm),"score")
}
\keyword{misc}

\eof
\name{coincidence.matrix}
\alias{coincidence.matrix}
\title{calculate the concordance/discordance matrix for
 Krippendorff's alpha}
\description{
 calculates the coincidence matrix for Krippendorff's alpha.
}
\usage{
coincidence.matrix(x)
}
\arguments{
  \item{x}{classifier by object matrix of classifications}
}
\details{
 probably of no use by itself.
}
\value{
  \item{statistic}{always NA - value is calculated by \code{kripp.alpha}}
  \item{coincidence.matrix}{the concordance/discordance matrix
   used in the calculation of alpha}
  \item{data.values}{a character vector of the original data values}
  \item{nmatchval}{the count of matches, used in calculation}
}
\references{Krippendorff, K. (1980) Content analysis: An introduction to
 its methodology. Beverly Hills, CA: Sage.}
\author{Jim Lemon}
\note{This is the initial step in calculating Krippendorff's alpha coefficient.}
\seealso{\code{\link{kripp.alpha}}}
\examples{
 # the "C" data from Krippendorff
 nmm<-matrix(c(1,1,NA,1,2,2,3,2,3,3,3,3,3,3,3,3,2,2,2,2,1,2,3,4,4,4,4,4,
 1,1,2,1,2,2,2,2,NA,5,5,5,NA,NA,1,1,NA,NA,3,NA),nrow=4)
 coincidence.matrix(nmm)
}
\keyword{misc}

\eof
\name{kendall.w}
\alias{kendall.w}
\title{Kendall's W coefficient of concordance}
\description{
 calculates Kendall's W coefficient of concordance
}
\usage{
 kendall.w(x,lambda,descending=TRUE,ranks=FALSE)
}
\arguments{
  \item{x}{matrix of scores or ranks}
  \item{lambda}{optional contrast coefficient vector or matrix}
  \item{descending}{whether high (default) or low scores represent top ranks}
  \item{ranks}{whether the values in \code{x} are scores or ranks}
}
\details{
 \code{kendall.w} will accept either a matrix or data frame of scores or ranks
 where the rows represent methods (usually raters) and the columns represent
 data objects. It will handle ties, but not missing values. By default it 
 assumes that numerically higher scores represent numerically lower ranks. A
 vector or matrix of contrast coefficients (which each must sum to zero) may 
 be supplied. A z-score approximation of the significance of each contrast will
 be displayed if \code{lambda} is present. The \code{ranks} argument allows the
 user to pass ranks directly to the function. If ranks are passed without
 setting \code{ranks} to TRUE and with \code{descending} TRUE, the order of
 the ranks will be reversed. For small values of k (methods), \code{kendall.w} 
 will try to lookup the tabled values for significance. For \code{k} greater
 than 7, a chi-squared approximation is returned. Only one of these values will
 be returned.
}
\value{
 \item{W}{value of W}
 \item{p.table}{whether the obtained W exceeded the table value for small N}
 \item{p.chisq}{the probability of the obtained chi-squared value for larger N}
}
\references{Siegel, S. & Castellan, N.J.Jr. (1988) Nonparametric
 statistics for the behavioral sciences. Boston, MA: McGraw-Hill.}
\author{Jim Lemon}
\note{Kendall's W may not be appropriate for nominal class data.}
\seealso{\code{\link{kripp.alpha}},\code{\link{cohen.kappa}}}
\keyword{misc}

\eof
\name{kripp.alpha}
\alias{kripp.alpha}
\title{calculate Krippendorff's alpha reliability coefficient}
\description{
 calculates the alpha coefficient of reliability proposed by Krippendorff
}
\usage{
 kripp.alpha(x, method="nominal"))
}
\arguments{
  \item{x}{classifier by object matrix of classifications}
  \item{method}{data level of x}
}
\details{
}
\value{
 \item{statistic}{value of alpha}
 \item{coincidence.matrix}{the concordance/discordance matrix
  used in the calculation of alpha}
 \item{data.values}{a character vector of the unique data values}
 \item{nmatchval}{the count of matches, used in calculation}
}
\references{
 Krippendorff, K. (1980) Content analysis: An introduction to
  its methodology. Beverly Hills, CA: Sage.
}
\author{Jim Lemon}
\note{Krippendorff's alpha coefficient is particularly useful where
 the level of measurement of classification data is higher than nominal
 or ordinal.}
\seealso{\code{\link{coincidence.matrix}}}
\examples{
 # the "C" data from Krippendorff
 nmm<-matrix(c(1,1,NA,1,2,2,3,2,3,3,3,3,3,3,3,3,2,2,2,2,1,2,3,4,4,4,4,4,
 1,1,2,1,2,2,2,2,NA,5,5,5,NA,NA,1,1,NA,NA,3,NA),nrow=4)
 # first assume the default nominal classification
 kripp.alpha(nmm)
 # now use the same data with the other three methods
 kripp.alpha(nmm,"ordinal")
 kripp.alpha(nmm,"interval")
 kripp.alpha(nmm,"ratio") 
}
\keyword{misc}

\eof
\name{mcnemar.mh}
\alias{mcnemar.mh}
\title{2 way reliability coefficient for nominal data}
\description{
 calculates a coefficient of reliability for nominal data
}
\usage{
mcnemar.mh(x)
}
\arguments{
  \item{x}{2x2 classification matrix or matrix of dichotomous
   classification scores.}
}
\details{
 \code{mcnemar.mh} calculates a reliability coefficient for two raters
  classifying n objects into two categories. It will accept either a 2x2
  classification matrix of counts of objects falling into two categories
  or a 2xn or nx2 matrix of classification scores.
}
\value{
  \item{kappa}{value of kappa}
  \item{Z}{the Z-score approximation}
  \item{p}{the probability of Z}
}
\references{Siegel, S. & Castellan, N.J.Jr. (1988) Nonparametric
 statistics for the behavioral sciences. Boston, MA: McGraw-Hill.}
\author{Jim Lemon}
\seealso{\code{\link{stuart.maxwell.mh}}}
\examples{
 xt<-table(sample(0:1,50,TRUE),sample(0:1,50,TRUE))
 mcnemar.mh(xt)
}
\keyword{misc}

\eof
\name{print.cohen.kappa}
\alias{print.cohen.kappa}
\title{prints kappa reliability coefficient for nominal data}
\description{
 prints the kappa coefficient and associated probability
}
\usage{
 print.cohen.kappa(x,...)
}
\arguments{
 \item{x}{an object of class "cohen.kappa" returned from \code{cohen.kappa}}
 \item{...}{arguments to be passed to \code{print}}
}
\value{
 nil
}
\author{Jim Lemon}
\keyword{misc}

\eof
\name{print.kendall.w}
\alias{print.kendall.w}
\title{displays Kendall's W information}
\description{
 prints the W coefficient, associated probability and optionally a table of 
 ranks
}
\usage{
 print.kendall.w(x,...)
}
\arguments{
 \item{x}{an object of class "kendall.w" returned from \code{kendall.w}}
 \item{...}{arguments to be passed to \code{print}}
}
\value{
 nil
}
\author{Jim Lemon}
\keyword{misc}

\eof
\name{print.kripp.alpha}
\alias{print.kripp.alpha}
\title{displays Krippendorff's alpha information}
\description{
 prints the Krippendorff's alpha coefficient
}
\usage{
 print.kripp.alpha(x,...)
}
\arguments{
 \item{x}{an object of class "kripp.alpha" returned from \code{kripp.alpha}}
 \item{...}{arguments to be passed to \code{print}}
}
\value{
 nil
}
\author{Jim Lemon}
\keyword{misc}

\eof
\name{print.stuart.maxwell}
\alias{print.stuart.maxwell}
\title{displays Stuart-Maxwell marginal homogeneity test information}
\description{
 prints the information from \code{stuart.maxwell.mh}
}
\usage{
 print.stuart.maxwell(x,...)
}
\arguments{
 \item{x}{an object of class "stuart.maxwell" returned from
  \code{stuart.maxwell}}
 \item{...}{arguments to be passed to \code{print}}
}
\value{
 nil
}
\author{Jim Lemon}
\keyword{misc}

\eof
\name{rater.bias}
\alias{rater.bias}
\title{coefficient of rater bias}
\description{
 calculates a coefficient of systematic bias between two raters
}
\usage{
rater.bias(x)
}
\arguments{
 \item{x}{CxC classification matrix or matrix of classification scores
  into C categories.}
}
\details{
 \code{rater.bias} calculates a reliability coefficient for two raters
  classifying n objects into any number of categories. It will accept either 
  a cxc classification matrix of counts of objects falling into c categories
  or a 2xn or nx2 matrix of classification scores.
}
\value{
  \item{statistic}{value of coefficient}
  \item{p}{the probability of the coefficient as a df 1 Chi-square variable}
}
\references{
 Bishop Y.M.M., Fienberg S.E. & Holland P.W. (1975) Discrete multivariate 
 analysis: theory and practice. Cambridge, Massachusetts: MIT Press.
}
\author{Jim Lemon}
\seealso{\code{\link{mcnemar.mh}}}
\examples{
 # fake a 2xn matrix of three way classification scores
 ratings<-matrix(sample(1:3,60,TRUE),nrow=2)
 rater.bias(ratings)
}
\keyword{misc}

\eof
\name{scores.to.counts}
\alias{scores.to.counts}
\title{transform a score matrix to a count matrix}
\description{
 transforms an object by classifier matrix of classification scores to
 an object by category matrix of classification counts
}
\usage{
scores.to.counts(scores)
}
\arguments{
  \item{scores}{object by classifier matrix of classification scores}
}
\details{
 usually called by \code{cohen.kappa}
}
\value{
  \item{counts}{an object by category matrix of counts}
  \item{scores.to.counts}{the concordance/discordance matrix
   used in the calculation of alpha}
  \item{data.values}{a character vector of the original data values}
  \item{nmatchval}{the count of matches, used in calculation}
}
\author{Jim Lemon}
\note{There seems to be no established convention for whether objects(cases)
 should be rows (as they are here) or columns. Make sure to transpose as
 below if necessary.}
\seealso{\code{\link{cohen.kappa}}}
\examples{
 # the "C" data from Krippendorff
 nmm<-matrix(c(1,1,NA,1,2,2,3,2,3,3,3,3,3,3,3,3,2,2,2,2,1,2,3,4,4,4,4,4,
 1,1,2,1,2,2,2,2,NA,5,5,5,NA,NA,1,1,NA,NA,3,NA),nrow=4)
 # remember to transpose the data to the expected format
 scores.to.counts(t(nmm))
}
\keyword{misc}

\eof
\name{stuart.maxwell.mh}
\alias{stuart.maxwell.mh}
\title{between rater concordance coefficient for classification}
\description{
 calculates the coefficient of concordance for two raters
}
\usage{
stuart.maxwell.mh(x)
}
\arguments{
 \item{x}{cxc classification matrix or matrix of classification scores
  into c categories.}
}
\details{
 \code{stuart.maxwell.mh} calculates a reliability coefficient for two raters
  classifying n objects into any number of categories. It will accept either 
  a cxc classification matrix of counts of objects falling into c categories
  or a cxn or nxc matrix of classification scores.
}
\value{
  \item{statistic}{value of coefficient}
  \item{p}{the probability of the coefficient as a Chi-square variable}
}
\references{
 Stuart A.A. (1955) A test for homogeneity of the marginal 
 distributions in a two-way classification. Biometrika, 42, 412-416.
 
 Maxwell A.E. (1970) Comparing the classification of subjects by two 
 independent judges. British Journal of Psychiatry, 116, 651-655.
}
\author{Jim Lemon}
\seealso{\code{\link{rater.bias}}}
\examples{
 # fake a 2xn matrix of three way classification scores
 ratings<-matrix(sample(1:3,60,TRUE),nrow=2)
 stuart.maxwell.mh(ratings)
}
\keyword{misc}

\eof
\name{tiecorr}
\alias{tiecorr}
\title{correction for tied ranks}
\description{
 calculates a correction for tied ranks
}
\usage{
 tiecorr(rankarray)
}
\arguments{
  \item{rankarray}{matrix of ranks}
}
\details{
 \code{tiecorr} calculates a correction for tied ranks that is appropriate for
 Kendall's W and the Spearman rank-order correlation coefficient.
}
\value{
  \item{tie3margsum}{correction factor}
}
\references{Siegel, S. & Castellan, N.J.Jr. (1988) Nonparametric
 statistics for the behavioral sciences. Boston, MA: McGraw-Hill.}
\author{Jim Lemon}
\seealso{\code{\link{kendall.w}}}
\keyword{misc}

\eof
\name{wtpc}
\alias{wtpc}
\title{calculate weighted percentages for nominal classification data}
\description{
 calculates weighted percentages for nominal classification data
}
\usage{
wtpc(x, n.methods, n.objects, type=c("count","score"))
}
\arguments{
  \item{x}{vector, data frame or matrix of ratings}
  \item{n.methods}{the number of methods (e.g. raters) used}
  \item{n.objects}{the number of objects rated or classified}
  \item{type}{whether the data represent counts of objects in categories
  or scores for objects by methods}
}
\details{
 \code{wtpc} will accept a vector (if only one method is used) matrix or 
 data frame in which values represent counts of objects (rows) classified 
 as categories (columns), or the same objects in which values represent 
 categorizations of those objects. The default is to assume counts 
 and the operator \bold{must} specify if scores are used. The formula
 used is: \code{wtpc = 100/n.methods * sum(category counts)/n.objects}.
}
\value{
  \item{wtpc}{vector of weighted percentages of occurrence of categories}
}
\author{Jim Lemon}
\note{This is a convenience function for calculating the frequencies of
category occurrences in ratings where all methods may not recognize the
same objects as belonging to the available categories.}
\examples{
 # the "C" data from Krippendorff
 nmm<-matrix(c(1,1,NA,1,2,2,3,2,3,3,3,3,3,3,3,3,2,2,2,2,1,2,3,4,4,4,4,4,
 1,1,2,1,2,2,2,2,NA,5,5,5,NA,NA,1,1,NA,NA,3,NA),nrow=4)
 # Krippendorff's data is classifier by object and must be transposed
 wtpc(t(nmm),4,12,"score")
}
\keyword{misc}

\eof
